@@ -1,5 +1,5 @@
 # ----------------------------------------------------------------------------
-# Copyright (c) 2016-2022, QIIME 2 development team.
+# Copyright (c) 2016-2023, QIIME 2 development team.
 #
 # Distributed under the terms of the Modified BSD License.
 #
@@ -11,8 +11,7 @@ import qiime2.plugin
 import q2_taxa
 
 from q2_types.feature_data import FeatureData, Taxonomy, Sequence
-from q2_types.feature_table import FeatureTable, Frequency
-
+from q2_types.feature_table import FeatureTable, Frequency, PresenceAbsence
 
 from . import barplot, collapse, filter_table, filter_seqs
 import q2_taxa._examples as ex
@@ -180,17 +179,25 @@ plugin.visualizers.register_function(
     function=barplot,
     inputs={
         'taxonomy': FeatureData[Taxonomy],
-        'table': FeatureTable[Frequency]
+        'table': FeatureTable[Frequency | PresenceAbsence]
     },
-    parameters={'metadata': qiime2.plugin.Metadata},
+    parameters={'metadata': qiime2.plugin.Metadata,
+                'level_delimiter': qiime2.plugin.Str},
     input_descriptions={
         'taxonomy': ('Taxonomic annotations for features in the provided '
                      'feature table. All features in the feature table must '
                      'have a corresponding taxonomic annotation. Taxonomic '
                      'annotations that are not present in the feature table '
-                     'will be ignored.'),
+                     'will be ignored. If no taxonomy is provided, the '
+                     'feature IDs will be used as labels.'),
         'table': 'Feature table to visualize at various taxonomic levels.'},
-    parameter_descriptions={'metadata': 'The sample metadata.'},
+    parameter_descriptions={
+        'metadata': 'The sample metadata.',
+        'level_delimiter': 'Attempt to parse hierarchical taxonomic '
+                           'information from feature IDs by separating '
+                           'levels with this character. This parameter '
+                           'is ignored if a taxonomy is provided as input.'
+        },
     name='Visualize taxonomy with an interactive bar plot',
     description='This visualizer produces an interactive barplot visualization'
                 ' of taxonomies. Interactive features include multi-level '
